#
# spec file for package libtunepimp
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libtunepimp
Version:        0.5.3
Release:        170.2
Summary:        Library That Provides Access to the MusicBrainz Server
License:        LGPL-2.1+
Group:          System/Libraries
Url:            http://www.musicbrainz.org/
# upstream ftp seems no longer available - see:
#  ftp://ftp.musicbrainz.org/pub/musicbrainz
Source0:        libtunepimp-%{version}.tar.bz2
Source1:        baselibs.conf
Patch0:         %{name}-fixes.patch
Patch1:         %{name}-ltdl.patch
#PATCH-FIX-UPSTREAM marguerite@opensuse.org - compare floating-point numbers correctly in configure script
Patch2:         libtunepimp-configure-taglib-floatpoint-version-comparsion.patch
#PATCH-FIX-OPENSUSE alarrosa@suse.com - make it possible to compare taglib versions such as 1.9.1
Patch3:         libtunepimp-configure-taglib-two-dots-in-version-fix.patch
# Patched code is built by default.
# Use rpmbuild -D 'BUILD_ORIG 1' to build original code.
# Use rpmbuild -D 'BUILD_ORIG 1' -D 'BUILD_ORIG_ADDON 1' to build patched build plus original as addon.
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bc
BuildRequires:  curl-devel
BuildRequires:  flac-devel
BuildRequires:  gcc-c++
BuildRequires:  libexpat-devel
BuildRequires:  libmpcdec-devel
BuildRequires:  libmusicbrainz-devel
BuildRequires:  libofa-devel
BuildRequires:  libtool
BuildRequires:  libvorbis-devel
BuildRequires:  readline-devel
BuildRequires:  taglib-devel
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?BUILD_ORIG}
BuildRequires:  mad-devel
BuildRequires:  mpeg4ip-devel
%if 0%{?BUILD_ORIG_ADDON}
Provides:       patched_subset
%else
Provides:       %{name}-orig-addon = %{version}
Obsoletes:      %{name}-orig-addon < %{version}
%endif
%else
Provides:       patched_subset
%endif
%if 0%{?BUILD_ORIG}
%if ! 0%{?BUILD_ORIG_ADDON}
Obsoletes:      libtunepimp-mad
%endif
%endif

%description
MusicBrainz is the second generation incarnation of the CD Index. This
server is designed to enable Audio CD, MP3, and Vorbis players to
download metadata about the music they are playing.

%package -n libtunepimp5
Summary:        Library That Provides Access to the MusicBrainz Server
Group:          System/Libraries
Requires:       %{name} >= %{version}

%description -n libtunepimp5
MusicBrainz is the second generation incarnation of the CD Index. This
server is designed to enable Audio CD, MP3, and Vorbis players to
download metadata about the music they are playing.

%if 0%{?BUILD_ORIG}
%if 0%{?BUILD_ORIG_ADDON}
%package orig-addon
Summary:        Library That Provides Access to the MusicBrainz Server
Group:          System/Libraries
Requires:       %{name} = %{version}
Supplements:    %{name}
Provides:       libtunepimp-mad
Obsoletes:      libtunepimp-mad < %{version}

%description orig-addon
MusicBrainz is the second generation incarnation of the CD Index. This
server is designed to enable Audio CD, MP3, and Vorbis players to
download metadata about the music they are playing.

%endif
%endif

%package devel
Summary:        Include Files and Libraries mandatory for Development
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version} libstdc++-devel

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%prep
%setup -q
%patch0
%patch1
%patch2 -p1
%patch3 -p1

%build
autoreconf -fiv
%if 0%{?BUILD_ORIG}
# Aliasing problems in mp4.cpp:
export CXXFLAGS="%{optflags} -fno-strict-aliasing"
%endif
%configure \
  --disable-static \
  --with-pic
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
%if ! 0%{?BUILD_ORIG}
rm -f %{buildroot}%{_libdir}/tunepimp/plugins/mp3.tpp
rm -f %{buildroot}%{_libdir}/tunepimp/plugins/mp4.tpp
%endif
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libtunepimp5 -p /sbin/ldconfig

%postun -n libtunepimp5 -p /sbin/ldconfig

%files
%defattr(-, root, root)
%doc AUTHORS ChangeLog COPYING README.LGPL TODO
%dir %{_libdir}/tunepimp
%{_bindir}/*
%dir %{_libdir}/tunepimp/plugins
%{_libdir}/tunepimp/plugins/flac.tpp
%{_libdir}/tunepimp/plugins/mpc.tpp
%{_libdir}/tunepimp/plugins/speex.tpp
%{_libdir}/tunepimp/plugins/tta.tpp
%{_libdir}/tunepimp/plugins/vorbis.tpp
%{_libdir}/tunepimp/plugins/wav.tpp
%{_libdir}/tunepimp/plugins/wma.tpp
%{_libdir}/tunepimp/plugins/wv.tpp
%if 0%{?BUILD_ORIG}
%if 0%{?BUILD_ORIG_ADDON}
%files orig-addon
%defattr(-, root, root)
%endif
%{_libdir}/tunepimp/plugins/mp3.tpp
%{_libdir}/tunepimp/plugins/mp4.tpp
%endif

%files -n libtunepimp5
%defattr(-, root, root)
%{_libdir}/lib*.so.*

%files devel
%defattr(-, root, root)
%doc examples/Makefile* examples/*c
%{_includedir}/*
%{_libdir}/lib*.so

%changelog
* Wed Apr  6 2016 alarrosa@suse.com
- Added libtunepimp-configure-taglib-two-dots-in-version-fix.patch
  so it's possible to compare taglib versions like 1.9.1 with
  the minimum required 1.4 version
* Thu Jan 14 2016 i@marguerite.su
- add libtunepimp-configure-taglib-floatpoint-version-comparsion.patch
  * TW's taglib-devel (libtag-devel) is 1.10, but libtunepimp
    used "expr" to compare it w/ 1.4, whose result is not correct.
  * use "bc -l" command to correctly compare those floating point
    numbers.
* Wed Jun 10 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Add baselibs.conf to sources
- Update dependencies
- Remove obsolete/provides for unsupported releses of SLE/openSUSE
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Mon Aug  8 2011 crrodriguez@opensuse.org
- Fix build with newer curl
* Sun May  1 2011 toddrme2178@gmail.com
- Added 32bit compatibility libraries
- Removed self-obsoletes (fix for RPMLINT warning)
- Removed test for obsolete openSUSE version
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Tue Jun  9 2009 coolo@novell.com
- fix build
* Wed Aug 27 2008 crrodriguez@suse.de
- fix build, libexpat-devel buildRequire is needed here, not
  as a dependency for libmusicbrainz-devel
* Thu May 22 2008 crrodriguez@suse.de
- disable unusable static libraries
* Tue Apr 15 2008 schwab@suse.de
- Fix use of libltdl interface.
* Fri Jan 18 2008 meissner@suse.de
- added zlib-devel to BuildRequires
* Wed Oct 24 2007 meissner@suse.de
- fixed gcc43 build
* Wed Jul 25 2007 sbrabec@suse.cz
- Updated to version 0.5.3:
  * Support for FLAC 1.1.3.
  * Fixed linking of the wav plugin.
  * Fixed crash on extracting PUID from XML.
- Split package according to shared library packaging policy.
* Fri Apr 13 2007 tiwai@suse.de
- fixed build with FLAC 1.1.4.
* Fri Oct 20 2006 sbrabec@suse.cz
- Updated to version 0.5.2:
  * Case insensitive checking for the .mp3 extension
  * Fallback to ID3v2 TDRC if TDRL is not found
  * Ignore "MP3ext" in the padding area of ID3 tags
  * Removed track lookup parts of libtunepimp
  * WavPack, Speex and The True Audio metadata plugins
  * Fixed non-album tracks renaming/moving
  * Trivial change to id3tag to read tags empty ID3 frames
  * Python bindings fixes
  * Fixed checking for end of stream in Ogg Vorbis and FLAC plugins
  * Added decoding to MPC plugin
  * New acoustic fingerprint technology - MusicDNS
  * New file name format variable %%albumtracks
  * New plugins: Musepack, WMA, MP4
  * Setting TDTG frame in ID3 tags
- Do not try to build mad support in distributable build.
- Removed split mad support.
* Mon Jul 31 2006 sbrabec@suse.cz
- Fixed stack overflow in lookuptools.cpp (#191496, CVE-2006-3600).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 10 2006 sbrabec@suse.cz
- Updated to version 0.4.1.
* Wed Nov  9 2005 sbrabec@suse.cz
- Fixed devel dependencies.
- Removed unneeded static modules and .la files for modules.
- Make mad split optional.
* Thu Oct 27 2005 rguenther@suse.de
- fixes for gcc 4.1 compilation.
* Wed Apr  6 2005 adrian@suse.de
- fix linking, libtunepimp used functions from libz, but didn't
  link against.
* Wed Mar  9 2005 adrian@suse.de
- avoid dependencies to main package
* Thu Jan 13 2005 adrian@suse.de
- make libtunepimp plugable. All TRM decoders are now plugins.
  We should do the same with the MetaFile readers to get rid
  off the dependencies in libtunepimp.
* Tue Aug 10 2004 adrian@suse.de
- Provides/Obsoletes trm package
* Fri Aug  6 2004 adrian@suse.de
- update to version 0.3.0
* Fri Apr 16 2004 ro@suse.de
- remove un-neccessary version line in devel subpackage
* Sun Jan 11 2004 adrian@suse.de
- add %%run_ldconfig
* Sun Aug 17 2003 ro@suse.de
- changed dependency for devel package
* Tue Aug 12 2003 sbrabec@suse.cz
- New SuSE package from libtunepimp.
